<?php

// Exit if accessed directly.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if ( ! class_exists('Carousel_Block') ) {

	class Carousel_Block {

		public function __construct() {
			
			add_action('init',  array( $this, 'register_block_action') );
	
		}
	
		public function register_block_action() {
			
			if ( ! function_exists( 'register_block_type' ) ) return;
	
			$script_slug = 'carousel-block-js';
			$style_slug = 'carousel-block-style-css';
			$editor_style_slug = 'carousel-block-editor-css';
	
			wp_register_script(
				$script_slug, // Handle.
				plugin_dir_url( __FILE__ ) . 'carousel-block/dist/blocks.build.js', // Block.build.js: We register the block here. Built with Webpack.
				array(  'wp-blocks', 'wp-i18n', 'wp-element', 'wp-editor' ) // Dependencies, defined above.
			);
	
			// Styles.
			wp_register_style(
				$style_slug, // Handle.
				plugin_dir_url( __FILE__ ) .  'carousel-block/dist/blocks.style.build.css', // Block style CSS.
				array( 'wp-blocks' ) // Dependency to include the CSS after it.
			);
	
			wp_register_style(
				$editor_style_slug, // Handle.
				plugin_dir_url( __FILE__ ) . 'carousel-block/dist/blocks.editor.build.css', // Block editor CSS.
				array( 'wp-edit-blocks' ) // Dependency to include the CSS after it.
			);
	
			register_block_type(
				'carousel/block',  // Block name with namespace
					array(
						'style' => $style_slug, // General block style slug
						'editor_style' => $editor_style_slug, // Editor block style slug
						'editor_script' => $script_slug,  // The block script slug
						'attributes' => array(
							'images' => array(
								'type' => 'string',
								'default' => '[]',
							),
							'native_shortcode' => array(
								'type' => 'string',
								'default' => '',
							),
							'columns' => array(
								'type' => 'number',
								'default' => 5,
							),
							'style_boxshadow' => array(
								'type' => 'boolean',
								'default' => true,
							),
						),
						'render_callback' => array( $this, 'render_callback' ),
					)
				);
		}
		
		public function render_callback( $attributes, $content = null, $context = 'frontend' ) {
			
			if ( ! is_admin() && icp_gut_search_block( 'carousel/block' ) ) {
				
				return $attributes['native_shortcode'];
					
			}
	
			return '';
			
		}
	
	}
	
	new Carousel_Block();

}